@@ -91,9 +91,10 @@ fftw_r2c <- function(data, HermConj=1) {
         nc <- as.integer(n/2) +1
     }    
 
-    out <- .C("fft_r2c", as.integer(n), as.double(data),
+    out <- .C("cfft_r2c", as.integer(n), as.double(data),
               res=complex(nc),
-              as.integer(HermConj))
+              as.integer(HermConj),
+              PACKAGE="fftwtools")
     return(out$res)
 }
 
@@ -115,8 +116,9 @@ fftw_c2r <- function(data, HermConj=1, n=NULL) {
     }
       
     ## only pass what is needed to the C function
-    out <- .C("fft_c2r", as.integer(n), as.complex(data[1:nc]),
-              res=double(n))
+    out <- .C("cfft_c2r", as.integer(n), as.complex(data[1:nc]),
+              res=double(n),
+              PACKAGE = "fftwtools")
     
     return(out$res)
 }
@@ -126,8 +128,9 @@ fftw_c2c <- function(data, inverse=0) {
 
     n <- length(data)
     
-    out <- .C("fft_c2c", as.integer(n), as.complex(data),
-              res=complex(n), as.integer(inverse))
+    out <- .C("cfft_c2c", as.integer(n), as.complex(data),
+              res=complex(n), as.integer(inverse),
+              PACKAGE = "fftwtools")
     
     return(out$res)
 }
@@ -141,10 +144,11 @@ mvfftw_r2c <- function(data, HermConj=1, fftplanopt=0) {
     nc <- as.integer(n/2) +1
        
     
-    out <- .C("mvfft_r2c", as.integer(n), as.integer(m),
+    out <- .C("cmvfft_r2c", as.integer(n), as.integer(m),
               as.double(data),
               res=matrix(as.complex(0), nc, m),
-              as.integer(fftplanopt))
+              as.integer(fftplanopt),
+              PACKAGE="fftwtools")
 
     res <- as.matrix(out$res)
 
@@ -187,9 +191,10 @@ mvfftw_c2r <- function(data, HermConj=1, n=NULL, fftplanopt=0) {
         nc <- as.integer(n/2) + 1
     }
         
-    out <- .C("mvfft_c2r", as.integer(n), as.integer(m),
+    out <- .C("cmvfft_c2r", as.integer(n), as.integer(m),
               as.complex(data[1:nc,]),
-              res=matrix(as.double(0), n, m), as.integer(fftplanopt))
+              res=matrix(as.double(0), n, m), as.integer(fftplanopt),
+              PACKAGE="fftwtools")
 
     return(out$res)
 }
@@ -200,10 +205,11 @@ mvfftw_c2c <- function(data, inverse=0, fftplanopt=0) {
     n <- dim(data)[1]
     m <- dim(data)[2]
     
-    out <- .C("mvfft_c2c", as.integer(n), as.integer(m),
+    out <- .C("cmvfft_c2c", as.integer(n), as.integer(m),
               as.complex(data),
               res=matrix(as.complex(0), n, m),
-              as.integer(inverse), as.integer(fftplanopt))
+              as.integer(inverse), as.integer(fftplanopt),
+              PACKAGE="fftwtools")
     
     return(out$res)
 }
@@ -217,21 +223,17 @@ fftw_r2c_2d <- function(data, HermConj=1) {
 
     nR <- dim(data)[1]
     nC <- dim(data)[2]
-    nRc <- floor(nR/2) +1
-    
-    isEven <- 1 - (nR %% 2)
-    idxRowAppend <- NULL
-    
-    if(isEven) {
-        idxRowAppend <- (nRc -1):2
-    } else {
-        idxRowAppend <- nRc:2
-    }
+
+    nRdiv2 <- nR/2
+    nRc <- floor(nRdiv2) +1
+    idxRowAppend <- ceiling(nRdiv2):2
     
+
     ##correct for the fact the c call is column-major
 
-    out <- .C("fft_r2c_2d", as.integer(nC), as.integer(nR),
-              as.double(data), res=matrix(as.complex(0), nRc , nC))
+    out <- .C("cfft_r2c_2d", as.integer(nC), as.integer(nR),
+              as.double(data), res=matrix(as.complex(0), nRc , nC),
+              PACKAGE="fftwtools")
 
     res <- as.matrix(out$res)
     if(HermConj==1 && nR > 2) {
@@ -265,10 +267,11 @@ fftw_c2c_2d <- function(data, inverse=0) {
 
     ##we correct for the fact the c call is column-major
 
-    out <- .C("fft_c2c_2d", as.integer(nC), as.integer(nR),
+    out <- .C("cfft_c2c_2d", as.integer(nC), as.integer(nR),
               as.complex(data),
               res=matrix(as.complex(0), nR , nC),
-              as.integer(inverse))
+              as.integer(inverse),
+              PACKAGE="fftwtools")
 
     return(out$res)
 }
